@@ -6,6 +6,9 @@
 #include "weatherforecasttest.h"
 #include <kweathercore/dailyweatherforecast.h>
 #include <kweathercore/hourlyweatherforecast.h>
+
+#include <QJsonObject>
+
 void WeatherForecastTest::testHourlyMerge()
 {
     auto date = QDateTime({2022, 8, 4}, {22, 0});
@@ -26,7 +29,7 @@ void WeatherForecastTest::testDailyMerge()
         d.setDate(date.addDays(i));
         vec.push_back(d);
     }
-    d1.setDailyWeatherForecast(vec);
+    d1.setDailyWeatherForecast(std::move(vec));
 
     QCOMPARE(d1.dailyWeatherForecast().size(), 3);
 }
